@@ -11,10 +11,10 @@ class printr:
             for item in items:
                 if message:
                     message += ' '
+                if isinstance(item, dict) or isinstance(item, list):
+                    item = json.dumps(item, indent=4)
                 message += str(item)
-        if isinstance(message, dict) or isinstance(message, list):
-            message = json.dumps(message, indent=4)
-        elif current_time:
+        if current_time:
             current_time = datetime.now()
             current_time = current_time.strftime('%H:%M:%S:%f')
             message = f'{current_time}: {message}'
@@ -34,4 +34,4 @@ class current_time:
 
 class same_line:
     def __init__(self, *items, current_time=False):
-        printr(*items, same_line=same_line, current_time=current_time,)
\ No newline at end of file
+        printr(*items, same_line=same_line, current_time=current_time)
\ No newline at end of file
